@@ -636,7 +636,7 @@ class Fdfs_client(object):
         else:
             self.upload_chunks_by_filename(filename, chunk_size)
 
-    def upload_chunks_by_filename(self, filename: str, chunk_size=1024 * 500, max_retry_count=5):
+    def upload_chunks_by_filename(self, filename: str, chunk_size=1024 * 500):
         ext_name = os.path.splitext(filename)[-1]
         ext_name = ext_name.replace('.', '')
         with open(filename, 'rb') as fin:
@@ -645,18 +645,12 @@ class Fdfs_client(object):
             remote_fileid = ret['Remote file_id']
             buffer = fin.read(chunk_size)
             while buffer:
-                retry_count = 0
-                while retry_count < max_retry_count:
-                    try:
-                        self.append_by_buffer(buffer, remote_fileid)
-                        buffer = fin.read(chunk_size)
-                        break
-                    except Exception as e:
-                        retry_count += 1
-                        log.exception('smart upload fail, retry now. fileid: %s, retry_count: %d, exception: %s',
-                                      remote_fileid, retry_count, e)
-                        if retry_count >= max_retry_count:
-                            ret = self.delete_file(remote_fileid)
-                            raise FDFSError('smart upload failed', remote_fileid, ret)
-                        else:
-                            time.sleep(5)
+                try:
+                    self.append_by_buffer(buffer, remote_fileid)
+                    # todo 若fin.read 报错，则会导致文件上传错误。
+                    buffer = fin.read(chunk_size)
+                except Exception as e:
+                    log.exception('smart upload fail, retry now. fileid: %s, exception: %s',
+                                  remote_fileid, e)
+                    ret = self.delete_file(remote_fileid)
+                    raise FDFSError('smart upload failed', remote_fileid, ret)
